@@ -124,16 +124,15 @@
 #' # show first five exceedances:
 #' res$exceedance[1:5, ]
 #'
-exceedance <-
-  function(data,
-           x = t,
-           y = temp,
-           threshold,
-           below = FALSE,
-           minDuration = 5,
-           joinAcrossGaps = TRUE,
-           maxGap = 2,
-           maxPadLength = FALSE) {
+exceedance <- function(data,
+                       x = t,
+                       y = temp,
+                       threshold,
+                       below = FALSE,
+                       minDuration = 5,
+                       joinAcrossGaps = TRUE,
+                       maxGap = 2,
+                       maxPadLength = FALSE) {
 
     # message("exceedance() is deprecated and will not be included in the next release of heatwaveR")
     # message("please use detecet_event() directly and set 'threshClim =' whatever your static threshold is")
@@ -199,7 +198,7 @@ exceedance <-
       intensity_cum_abs <- ts_y <- exceedance_no <- row_index <- index_peak <-  NULL
 
     exceedances <- exceedances_clim %>%
-      dplyr::mutate(row_index = 1:nrow(exceedances_clim),
+      dplyr::mutate(row_index = seq_len(nrow(exceedances_clim)),
                     exceedance_rel_thresh = ts_y - thresh) %>%
       dplyr::filter(stats::complete.cases(exceedance_no)) %>%
       dplyr::group_by(exceedance_no) %>%
